#####################################################################
#####################################################################
###################### Archived code for paper ######################
#####################################################################
#####################################################################

# Paper:   Synoptic processes of winter precipitation
#                 in the Upper Indus Basin
# Journal: Weather and Climate Dynamics (submitted)
# DOI:     #
# Authors: Jean-Philippe Baudouin, Michael Herzog, Cameron A. Petrie

####################################################################
# File purpose: Figure 2-8, Section Wind contribution
# Note:        
# Version:     08/07/2021
#####################################################################

## libraries, sources
#######################
  source("01_functions.R")

## Data
#########

  # From previous files
  load("data/ts_uvq.Rdata")

  # selection of timesteps analyses: winter and 10% highest W700
  sel_win <- which(as.numeric(format(pr_ind_era5_3h$time[-c(1,2,116880)], format="%m")) %in% c(10:12, 1:5))+2
  selQ <- sel_win[which(ts_uv[sel_win]>quantile(ts_uv[sel_win], .9))] # Q90% threshold: 2.763494
  sum(pr_ind_era5_3h$up[selQ])/sum(pr_ind_era5_3h$up[sel_win], na.rm=T) # Fraction of precipitation falling during the selected timesteps 0.5021534
  length(selQ) # Number of timesteps selected: 7784
  sum(pr_ind_era5_3h$up[which(as.numeric(format(pr_ind_era5_3h$time[-c(1,2,116880)],
                                                format="%m")) %in% c(6:9))], na.rm=T)/40 # Winter precipitation: 404.8085
  sum(pr_ind_era5_3h$up, na.rm=T)/40 # Annual precipitation: 910.4204



## Functions
##############

  
################################################################################
################################################################################  


#############################################################
########## Figure 2: Altitude horizontal composite ##########
#############################################################
  
  load("data/predictors_WD.Rdata")
  
  p1 <- plot_WD(z300, dz300_500, selQ-16, seq(-105,30,15), seq(-45,30,15)) # 578 -713.205  53 36
  p3 <- plot_WD(z300, dz300_500, selQ   , seq(-105,30,15), seq(-45,30,15)) # 591 -1082.692 66 36
  p5 <- plot_WD(z300, dz300_500, selQ+16, seq(-105,30,15), seq(-45,30,15)) # 597 -609.8414 72 36

  
  p <- ggarrange(p1 + labs(title="A) -2 days") + geom_path(aes(x=c(55,80), y=c(32,32)), size=1, colour="white"),
                 p3 + labs(title="B) no lag"),
                 p5 + labs(title="C) +2 days"),
                 nrow=1, common.legend=T, legend="bottom")

  ggsave("figures/Fig02_WD_comp_lagH.pdf", p, device="pdf", width=12, height=7)   
  
  rm(z300, dz300_500, dz500_700);gc() # Datasets are too big to keep them in memory


#######################################################
########## Figure 3: Cross-section composite ##########
#######################################################

  
  load("data/vert_t32.Rdata")
  load("data/vert_z32.Rdata")
  load("data/vert_q32.Rdata")
  load("data/vert_v32.Rdata")
  
  
  # Mask for the surface on cross-section maps
  surf32 <- ag_era5(32, seq(55,80,.25))/g
  alt_out <- seq(0,15000,500)
  sel_alt <- c(1,3,5,7,8,10,12,14,16,19,23,27) # Altitude values to print

  p1 <- plot_vert(selQ-8)
  p3 <- plot_vert(selQ)
  p5 <- plot_vert(selQ+8)
  
  p2 <- plot_vert2(selQ-8)
  p4 <- plot_vert2(selQ)
  p6 <- plot_vert2(selQ+12)
  
  
  p <- grid.arrange(nrow = 3, heights = c(1,8,8), 
                    arrangeGrob(blank_ggplot("-1 day", fontface = "bold", hjust=0.3), blank_ggplot("no lag", fontface = "bold", hjust=0.7), 
                                blank_ggplot("+1 day", fontface = "bold", hjust=0.7), nrow=1),
                    arrangeGrob(nrow=1, widths=c(1,20,1),
                                blank_ggplot("Altitude (m)", angle=90, size=8, hjust=.3),
                                ggarrange(p1 + annotate("label", x=58, y=13500, label="A)", size=8, label.padding = unit(c(.4), "lines"), alpha=.5),
                                          p3 + annotate("label", x=58, y=13500, label="B)", size=8, label.padding = unit(c(.4), "lines"), alpha=.5),
                                          p5 + annotate("label", x=58, y=13500, label="C)", size=8, label.padding = unit(c(.4), "lines"), alpha=.5),
                                          nrow=1, common.legend=T, legend="bottom"),
                                blank_ggplot("Pressure (hPa)", angle=-90, size=8, hjust=.7)),
                    arrangeGrob(nrow=1, widths=c(1,20,1),
                                blank_ggplot("Altitude (m)", angle=90, size=8, hjust=.3),
                                ggarrange(p2 + annotate("label", x=58, y=13500, label="D)", size=8, label.padding = unit(c(.4), "lines"), alpha=.5),
                                          p4 + annotate("label", x=58, y=13500, label="E)", size=8, label.padding = unit(c(.4), "lines"), alpha=.5),
                                          p6 + annotate("label", x=58, y=13500, label="F)", size=8, label.padding = unit(c(.4), "lines"), alpha=.5),
                                          nrow=1, common.legend=T, legend="bottom"),
                                blank_ggplot("Pressure (hPa)", angle=-90, size=8, hjust=.7)))

  ggsave("figures/Fig03_WD_comp_lagV-2.pdf",p, device="pdf", width=12, height=10)   
  
  rm(z32, t32, v32, q32);gc()


  
##################################################
########## Figure 4: Wind 250 composite ##########
##################################################
  
  
  load("data/wind250.Rdata")
  
  p <- ggarrange(plot_jet2(selQ-32, "A) -4 days"),
                 plot_jet2(selQ-16, "B) -2 days"),
                 plot_jet2(selQ-0,  "C) no lag"),
                 plot_jet2(selQ+16, "D) +2 days"),
                 nrow=2, ncol=2, common.legend=T, legend="bottom")
  
  ggsave("figures/Fig41_ws250_comp-2.pdf", p, device="pdf", width=17, height=12)   
  
  rm(ws250);gc()
  
#######################################################
########## Figure 5: Geopotential Regression ##########
#######################################################
  
  load("data/predictors_WD.Rdata")
  n <- 40 # Arbitrary number of PC: the point is to be able to identify a pattern and being able to explain it
  reg2 <- lm(ts_uv[sel_win] ~ z300$EOF$x[sel_win,1:n] + dz300_500$EOF$x[sel_win,1:n] + dz500_700$EOF$x[sel_win,1:n])
  R2 <- round(1-var(reg2$residuals)/var(ts_uv[sel_win]),3) # coefficient of determination: .852
  
  ## The plot of the coefficient for each predictor field
  data_reg1 <- data.frame(value = z300$EOF$rotation[,1:n]%*%coef(reg2)[1:n+1], x = z300$map[,1], y = z300$map[,2])
  data_reg2 <- data.frame(value = dz300_500$EOF$rotation[,1:n]%*%coef(reg2)[1:n+1+n], x = z300$map[,1], y = z300$map[,2])
  data_reg3 <- data.frame(value = dz500_700$EOF$rotation[,1:n]%*%coef(reg2)[1:n+1+2*n], x = z300$map[dz500_700$sel,1], y = z300$map[dz500_700$sel,2])
  
  max <- max(c(max(abs(data_reg1$value)), max(abs(data_reg2$value)), max(abs(data_reg3$value))))
  p1 <- plot_reg(data_reg1, max, label = "B) Z300", x=59)
  p2 <- plot_reg(data_reg2, max, label = "C) dZ_UP", x=61)
  p3 <- plot_reg(data_reg3, max, label = "D) dZ_LW", x=61)
  
  data_pt <- data.frame(v=ts_uv[sel_win], z=predict(reg2))
  p4 <- plot_pts(data_pt, R2, label="A)") + labs(y= "Predicted W700")
  
  p <- ggarrange(p4 + theme(plot.margin  = margin(30,10,0,0)), p1, p2, p3, ncol = 2, nrow=2, common.legend=T, legend="bottom")
  
  ggsave("figures/Fig05_WD_regZ_dZ.pdf", p, device="pdf", width=12, height=12)   
  
  rm(z300, dz300_500, dz500_700);gc()

  
#################################################################
########## Figure 6: Lead/Lag composites of timeseries ##########
#################################################################
  
  # Computing the contributions of each predictors of the regression just above
  ts_z300_2    <-      z300$EOF$x[,1:n]%*%coef(reg2)[1:n+1]
  ts_dz500_300 <- dz300_500$EOF$x[,1:n]%*%coef(reg2)[1:n+1+n]
  ts_dz700_500 <- dz500_700$EOF$x[,1:n]%*%coef(reg2)[1:n+1+2*n]

  data_ts <- data.frame(Z300 = ts_z300_2, dZ_UP = ts_dz500_300, dZ_LW = ts_dz700_500)

  data_tsa <- data.frame(pred   = c(ts_z300_2 + ts_dz500_300 + ts_dz700_500) + coef(reg2)[1],
                         dZa_UP = data_ts$dZ_UP - predict(lm(dZ_UP ~ Z300, data = data_ts[sel_win,]), data_ts),
                         dZa_LW = data_ts$dZ_LW - predict(lm(dZ_LW ~ Z300, data = data_ts[sel_win,]), data_ts),
                         W700   = ts_uv,
                         Q700   = ts_q*1000,
                         Q700a  = unseas(c(ts_q)*1000, ny = 40, h=4),
                         Pr     = pr_ind_era5_3h$up*8,
                         m      = as.numeric(format(pr_ind_era5_3h$time, format="%m")))

  data_tsa$Z300 <- data_ts$Z300 + data_ts$dZ_UP + data_ts$dZ_LW - data_tsa$dZa_UP - data_tsa$dZa_LW
  intercept <- coef(reg2)[1]
  save(data_tsa, intercept, selQ, file="data/ts_WD.Rdat")


  lag_all  <- t(sapply(-24:24, function(i) apply(data_tsa[selQ+i,], 2, mean, na.rm=T)))

  data <- data.frame(val  = c(lag_all[,c("Pr")], rep(0, 49*2),lag_all[,c("W700", "Q700")], rep(0, 49*2),
                              lag_all[,c("Z300", "dZa_UP", "dZa_LW")]), 
                     type = rep(1:10, each=49), lag = rep(-24:24, 10)/8)

  p <- ggplot(data, aes(x=lag, y=val, group=type)) +
       geom_line(aes(colour=as.factor(type), linetype=as.factor(type)), size=1) +
       theme_plot + 
       theme(axis.title.y.right = element_text(vjust = -5, angle = 90),
            legend.box.margin = margin(0,0,0,40)) + 
       scale_x_continuous(expand = c(0,0), name = "Lag (days)") +
       scale_y_continuous(expand = c(0,0), limits = c(-.5, 11), breaks=seq(0,10,2),
                          name = expression(atop("W700 (m."*s^"-1"*")", "precipitation (mm."*day^"-1"*")")),
                         sec.axis = sec_axis(~., name = expression("Q700 (kg."*kg^"-1"*")"),
                                               breaks=seq(0,10,2),labels=seq(0,10,2)/1000)) +
       scale_colour_manual(values = c(brewer.pal(6, "Dark2")[1], rep("transparent",2), brewer.pal(6, "Dark2")[2:3],
                                     rep("transparent",2), brewer.pal(6, "Dark2")[4:6]), name = NULL,
                          labels=c("Precipitation", "", expression(bold(underline("Precipitation regression:"))),
                                   "W700", "Q700", "",
                                   expression(bold(underline("W700 prediction:"))), "Z300",
                                   "dZa_UP",
                                   "dZa_LW"),
                          guide = guide_legend(label.hjust = 0)) +
       scale_linetype_manual(values = c(1,0,0,2,3,0,0,2,2,2), name = NULL,
                             labels=c("Precipitation", "", expression(bold(underline("Precipitation regression:"))),
                                      "W700", "Q700", "",
                                      expression(bold(underline("W700 prediction:"))), "Z300",
                                      "dZa_UP",
                                      "dZa_LW"),
                             guide = guide_legend(label.hjust = 0))
  

  ggsave("figures/Fig06_compLag.pdf", p, device="pdf", width=12, height=10)   
  
  round(apply(data_tsa[selQ,],2, mean), 3) # Mean value of each timeseries at maximum W700
#  pred  dZa_UP dZa_LW   W700   Q700  Q700a     Pr      m   Z300 
#  3.673  1.380  0.325  4.073  3.287  0.809 10.440  4.249  1.281 
  
  
  
###########################################################
########## Quantile regression for Figures 7 & 8 ##########
###########################################################
  
  load("data/predictors_WD.Rdata")
  load("data/ts_WD.Rdata")
  
  which(z300$map$x == 80 & z300$map$y == 30)
  
  reg_q25 <- rq(pred ~ as.factor(m) + z300$unseas[591, selQ] + Z300,
                tau=.25, data = data_tsa[selQ,])
  low  <- selQ[which(predict(reg_q25) > data_tsa$pred[selQ])]
  reg_q75 <- rq(pred ~ as.factor(m) + z300$unseas[591, selQ] + Z300,
                tau=.75, data = data_tsa[selQ,])
  high <- selQ[which(predict(reg_q75) < data_tsa$pred[selQ])]
  
  save(low, high, file = "data/rq_W700.Rdata")
  
  ## Mean value of each timeseries for each composites, based on the QR:
  ## Lower W700 and higher W700
  round(apply(data_tsa[low,], 2, mean),1); round(apply(data_tsa[high,], 2, mean),1)
  #       pred dZa_UP dZa_LW   W700   Q700  Q700a     Pr      m   Z300 
  #Low     2.6    0.4    0.2    3.2    3.0    0.5    5.9    4.3    1.3 
  #High    4.9    2.4    0.5    5.3    3.6    1.2   16.8    4.2    1.3  
  
##############################################################################
########## Figure 7: Altitude horizontal composite based on W700 QR ##########
##############################################################################

  load("data/rq_W700.Rdata") 

  p <- arrangeGrob(nrow=2, widths=c(1, 10), heights = c(1, 20), 
                   blank_ggplot(""), 
                   arrangeGrob(blank_ggplot("-2 days", fontface = "bold"),
                               blank_ggplot("no lag", fontface = "bold"),
                               blank_ggplot("+2 days", fontface = "bold"), ncol=3), 
                   arrangeGrob(blank_ggplot("Lower UV700", angle = 90, fontface = "bold"), 
                               blank_ggplot("Higher UV700", angle = 90, fontface = "bold"), 
                               blank_ggplot(""), ncol=1, heights = c(3,3,1.5)), 
                   ggarrange(nrow=2, ncol=3, common.legend=T, legend="bottom",
                             plot_WD(z300, dz300_500, low - 16 , seq(-105,45,15), seq(-45,45,15)) +
                               annotate("label", x=54, y=47.5, label="A)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, low + 0  , seq(-105,45,15), seq(-45,45,15)) +
                               annotate("label", x=54, y=47.5, label="B)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, low + 16  , seq(-105,45,15), seq(-45,45,15)) +
                               annotate("label", x=54, y=47.5, label="C)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, high - 16 , seq(-105,45,15), seq(-45,45,15)) +
                               annotate("label", x=54, y=47.5, label="D)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, high + 0  , seq(-105,45,15), seq(-45,45,15)) +
                               annotate("label", x=54, y=47.5, label="E)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, high + 16  , seq(-105,45,15), seq(-45,45,15)) +
                               annotate("label", x=54, y=47.5, label="F)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5)))

  ggsave("figures/Fig07_WDdiff_comp_lagH.pdf", p, device="pdf", width=12, height=10)   

  rm(z300, dz300_500, dz500_700);gc()


###################################################################
########## Figure 8: 250 Wind composite based on W700 QR ##########
###################################################################
  
  
  load("data/rq_W700.Rdat")
  load("data/wind250.Rdata")
  
  p <- ggarrange(plot_jet2(low, "A) Lower UV700") +  theme(legend.box = "vertical"),
                 plot_jet2(high, "B) Higher UV700") + theme(legend.box = "vertical"),
                 nrow=2, common.legend=T, legend="bottom")
  ggsave("figures/Fig08_ws250_compQR.pdf", p, device="pdf", width=12, height=14)   
  
  
  
  
  
  