#####################################################################
#####################################################################
###################### Archived code for paper ######################
#####################################################################
#####################################################################

# Paper:   Synoptic processes of winter precipitation
#                 in the Upper Indus Basin
# Journal: Weather and Climate Dynamics (submitted)
# DOI:     #
# Authors: Jean-Philippe Baudouin, Michael Herzog, Cameron A. Petrie

####################################################################
# File purpose: Figure 9-12, Section moisture contribution
# Note:        
# Version:     09/07/2021
#####################################################################


## libraries, sources
#######################
  source("01_functions.R")

## Data
##############

  ## selection of timesteps analyses: winter and 10% highest W700
  load("data/ts_uvq.Rdata")
  sel_win <- which(as.numeric(format(pr_ind_era5_3h$time[-c(1,2,116880)], format="%m")) %in% c(10:12, 1:5))+2
  selQ <- sel_win[which(ts_uv[sel_win]>quantile(ts_uv[sel_win], .9))] # Q90% threshold: 2.763494


################################################################################
################################################################################

  # Correlation between W700 and seasonal anomaly of Q700
  cor(data_tsa$W700[sel_win], unseas(data_tsa$Q700, 40, 4)[sel_win]) # 0.4518098
  
  
  
############################################################
########## Figure 9: Composite precipitable water ##########
############################################################


  load("data/data_PW.Rdata")
  
  facW1 <- 0.02 # Scale for the arrows
  
  # Lead/lag plots
  p1 <- plot_PW(selQ-32) + labs(title="B) -4 days")
  p3 <- plot_PW(selQ-16) + labs(title="C) -2 days")
  p4 <- plot_PW(selQ-8)  + labs(title="D) -1 day")
  p5 <- plot_PW(selQ)    + labs(title="E) No lag")
  p6 <- plot_PW(selQ+8)  + labs(title="F) +1 day")
  p7 <- plot_PW(selQ+16) + labs(title="G) +2 days")
  

  data <- data.frame(value = apply(PW$data[,selQ], 1, mean), x = PW$map[,1], y = PW$map[,2])
  data$value <- data$value - apply(PW$unseas[,selQ], 1, mean)
  
  dataW <- data.frame(u = apply(um$data[, selQ], 1, mean) - apply(um$unseas[, selQ], 1, mean),
                      v = apply(vm$data[, selQ], 1, mean) - apply(vm$unseas[, selQ], 1, mean),
                      x = vm$map[,1], y = vm$map[,2])
  
  
  # Seasonal mean plot
  breaks <- seq(0,40,5)
  p <- ggplot(data, aes(x=x, y=y)) + 
    geom_raster(aes(fill=pmax(pmin(value, max(breaks)), min(breaks))), interpolate=T) +
    geom_raster(data=data_relief, aes(x=x, y=y, alpha=z), show.legend=F, interpolate=T) +
    geom_contour(aes(z=value), linetype="21", size=.5, breaks=breaks, color="grey30") +
    geom_contour(data = data_relief[data_relief$z < 15000,], aes(x = x, y = y, z = lsm),
                 breaks = 0.5, colour="black", size=1) +
    geom_segment(data=dataW,aes(x = x, y = y, xend=x+u*facW1, yend=y+v*facW1),
                 arrow = arrow(length = unit(0.15,"cm"))) +
    mask_up(size=1) +
    theme_map + noleg + coord_quickmap() +
    theme(plot.margin = margin(.5,.5,.5,.5,"cm")) +
    labs(x=NULL, y=NULL, title=NULL) +   
    scale_x_continuous(expand=c(0,-5), limits=c(min(data$x)-5, max(data$x)+5), breaks=seq(30,100,10)) +
    scale_y_continuous(expand=c(0,-5), limits=c(min(data$y)-5, max(data$y)+5)) +
    scale_alpha_continuous(range=c(0,.8)) +
    scale_fill_gradientn(colours=rev(matlab.like(101)),
                         limits = range(breaks), breaks = breaks,
                         name  = expression(bold("Precipitable water (mm)")),
                         guide = guide_colorbar(barwidth = 25, barheight = 1,
                                                title.position = "top", title.hjust=.5,
                                                ticks.colour = "grey50",
                                                ticks.linewidth = 2,
                                                label.hjust = .5, label.vjust = 1.3))
  
  legend_mean <- gtable_filter(ggplotGrob(p + theme(legend.position="bottom",
                                                    legend.text = element_text(size=16),
                                                    legend.title=element_text(size=20))),"guide-box")
  legend_anom <- gtable_filter(ggplotGrob(p1 + theme(legend.position="bottom", 
                                                     legend.text = element_text(size=16), 
                                                     legend.title=element_text(size=20))),"guide-box")
  
  
  # Wind arrow legend
  p_wind <- ggplot() +
    theme_plot + 
    scale_x_continuous(expand = c(0,0), limits = c(30, 100), breaks=NULL) +
    scale_y_continuous(expand = c(0,0), breaks = NULL, limits = c(-10, 5)) +
    labs(title = NULL, y = NULL, x = NULL) + coord_quickmap() +
    theme(panel.background = element_blank(),
          axis.ticks = element_blank(),
          plot.margin  = margin(t=0, b=0, r=1, l=1.75, unit="cm")) +
    geom_segment(data=data.frame(x=c(47,65,83), y=c(0,0,0),
                                 u=sqrt(c(50,100,150)**2/2),
                                 v=sqrt(c(50,100,150)**2/2)),
                 aes(x = x - u*facW1/2, y = y-v*facW1/2,
                     xend=x+u*facW1/2, yend=y+v*facW1/2),
                 arrow = arrow(length = unit(0.15,"cm"))) + 
    geom_text(data=data.frame(x=c(47,65,83), y=-rep(6,3), text=c("50","100","150")),
              aes(x=x, y=y, label=text), size = 5.5)
  
  
  ggsave("figures/Fig09_moisture_comp_lag_PW.pdf",   
         grid.arrange(nrow=2, heights=c(1,2),
                      arrangeGrob(nrow = 1, widths=c(1,1,1),
                                  p + labs(title="A) Seasonal mean"), 
                                  arrangeGrob(nrow=2,
                                              legend_mean, legend_anom),
                                  arrangeGrob(nrow=4, heights =c(.7,1.3,1,1), blank_ggplot(""), 
                                              blank_ggplot(expression(bold(atop("Vertical integral of water",
                                                                                "vapour flux (kg.m."*s^"-1"*")"))), size = 6, vjust=1),
                                              p_wind, blank_ggplot(""))),
                      arrangeGrob(nrow=2, p1, p3, p4, p5, p6, p7)),
         device="pdf", width=17, height=12)   
  
  rm(PW, um, vm); gc()

######################################################
########## Figure 10: Composite evaporation ##########
######################################################
  
  load("data/data_ET.Rdata")
  
  facW1 <- .5 # Scale for the arrows
  
  
  # Lead/lag plots
  p3 <- plot_ET(selQ-16) + labs(title="B) -2 days")
  p5 <- plot_ET(selQ)    + labs(title="C) No lag")
  p7 <- plot_ET(selQ+16) + labs(title="D) +2 days")
  
  data <- data.frame(value = apply(ET$data[,selQ], 1, mean), x = ET$map[,1], y = ET$map[,2])
  data$value <- -(data$value - apply(ET$unseas[,selQ], 1, mean))*8000 # 8 gets the 3hourly value to daily value
  
  dataW <- data.frame(u = apply(u10$data[, selQ], 1, mean) - apply(u10$unseas[, selQ], 1, mean),
                      v = apply(v10$data[, selQ], 1, mean) - apply(v10$unseas[, selQ], 1, mean),
                      x = v10$map[,1], y = v10$map[,2])
  
  
  

  # Seasonal mean plot
  # sel_sea select 
  sel_sea <- which(data_relief$lsm[which(data_relief$x %in% unique(dataW$x) & data_relief$y %in% unique(dataW$y))] < .5)
  breaks <- seq(0,8,1)
  p <- ggplot(data, aes(x=x, y=y)) + 
    geom_raster(aes(fill=pmax(pmin(value, max(breaks)), min(breaks))), interpolate=T) +
    geom_raster(data=data_relief, aes(x=x, y=y, alpha=z), show.legend=F, interpolate=T) +
    geom_contour(aes(z=value), linetype="21", size=.5, breaks=breaks, color="grey30") +
    geom_contour(data = data_relief[data_relief$z < 15000,], aes(x = x, y = y, z = lsm),
                 breaks = 0.5, colour="black", size=1) +
    geom_segment(data=dataW[sel_sea,],aes(x = x, y = y, xend=x+u*facW1, yend=y+v*facW1),
                 arrow = arrow(length = unit(0.15,"cm"))) +
    mask_up(size=1) +
    theme_map + noleg + coord_quickmap() +
    theme(plot.margin = margin(.5,.5,.5,.5,"cm")) +
    labs(x=NULL, y=NULL, title=NULL) +   
    scale_x_continuous(expand=c(0,-5), limits=c(min(data$x)-5, max(data$x)+5), breaks=seq(30,100,10)) +
    scale_y_continuous(expand=c(0,-5), limits=c(min(data$y)-5, max(data$y)+5)) +
    scale_alpha_continuous(range=c(0,.8)) +
    scale_fill_gradientn(colours=rev(matlab.like(101)),
                         limits = range(breaks), breaks = breaks,
                         name  = expression(bold("Evaporation (mm."*day^"-1"*")")),
                         guide = guide_colorbar(barwidth = 25, barheight = 1,
                                                title.position = "top", title.hjust=.5,
                                                ticks.colour = "grey50",
                                                ticks.linewidth = 2,
                                                label.hjust = .5, label.vjust = 1.3))
  
  legend_mean <- gtable_filter(ggplotGrob(p + theme(legend.position="bottom",
                                                    legend.text = element_text(size=16),
                                                    legend.title=element_text(size=20))),"guide-box")
  legend_anom <- gtable_filter(ggplotGrob(p3 + theme(legend.position="bottom",
                                                     legend.text = element_text(size=16),
                                                     legend.title=element_text(size=20))),"guide-box")
  
  
  p_wind <- ggplot() +
    theme_plot + 
    scale_x_continuous(expand = c(0,0), limits = c(30, 100), breaks=NULL) +
    scale_y_continuous(expand = c(0,0), breaks = NULL, limits = c(-10, 3)) +
    labs(title = NULL, y = NULL, x = NULL) + coord_quickmap() +
    theme(panel.background = element_blank(),
          axis.ticks = element_blank(),
          plot.margin  = margin(t=0, b=0, r=0, l=0, unit="cm")) +
    geom_segment(data=data.frame(x=c(47,65,83), y=c(0,0,0),
                                 u=sqrt(c(1, 3, 5)**2/2),
                                 v=sqrt(c(1, 3, 5)**2/2)),
                 aes(x = x - u*facW1, y = y-v*facW1,
                     xend=x+u*facW1, yend=y+v*facW1),
                 arrow = arrow(length = unit(0.15,"cm"))) + 
    geom_text(data=data.frame(x=c(47,65,83), y=-rep(6,3), text=c("1","3","5")),
              aes(x=x, y=y, label=text), size = 5.5)

  
  ggsave("figures/Fig10_moisture_comp_lag_E-2.pdf",   
         grid.arrange(nrow=3, heights=c(3,3,2),
                      p + labs(title="A) Seasonal mean"), p3, p5, p7,
                      arrangeGrob(nrow=2,
                                  legend_mean, legend_anom),
                      arrangeGrob(nrow=4, heights =c(.65,1,1,.65), blank_ggplot(""), 
                                  blank_ggplot("") + annotate("text", x= 0, y=0,
                                                              label = expression(bold("Sea surface wind (10m, m."*s^"-1"*")")),
                                                              size = 6, vjust=1),
                                  p_wind, blank_ggplot(""))),
         device="pdf", width=12, height=13)
  
  
  rm(ET, u10, v10); gc()

#############################################################
########## Quantile regression for Figures 11 & 12 ##########
#############################################################

  
  load("data/predictors_WD.Rdata")
  load("data/ts_WD.Rdata")
  
  test <- z300$unseas[c(585), selQ] - z300$unseas[c(595), selQ]
  reg_q25 <- rq(Q700 ~ as.factor(m) + test, tau=.25, data=data_tsa[selQ,])
  low  <- selQ[which(predict(reg_q25) > data_tsa$Q700[selQ])]
  reg_q75 <- rq(Q700 ~ as.factor(m) + test, tau=.75, data=data_tsa[selQ,])
  high <- selQ[which(predict(reg_q75) < data_tsa$Q700[selQ])]
  
  ## Mean value of each timeseries for each composites, based on the QR:
  ## Low Q700 and high Q700
  round(apply(data_tsa[low,], 2, mean),1); round(apply(data_tsa[high,], 2, mean),1)
  #       pred dZa_UP dZa_DW   W700   Q700  Q700a     Pr      m   Z300 
  #Low     3.6    1.1    0.2    3.8    2.3   -0.1    5.9    4.2    1.6 
  #High    3.8    1.7    0.4    4.4    4.2    1.6   14.8    4.2    1.1 
  


###############################################################################
########## Figure 11: Composite precipitatble water based on Q700 QR ##########
###############################################################################

  ## Legends
  legend_anom <- gtable_filter(ggplotGrob(plot_PW(1:2) +
                   theme(legend.position="bottom",
                         legend.text = element_text(size=16),
                         legend.title=element_text(size=20))),"guide-box")
  p_wind <- ggplot() +
    theme_plot + 
    scale_x_continuous(expand = c(0,0), limits = c(30, 100), breaks=NULL) +
    scale_y_continuous(expand = c(0,0), breaks = NULL, limits = c(-10, 5)) +
    labs(title = NULL, y = NULL, x = NULL) + coord_quickmap() +
    theme(panel.background = element_blank(),
          axis.ticks = element_blank(),
          plot.margin  = margin(t=0, b=0, r=.5, l=0, unit="cm")) +
    geom_segment(data=data.frame(x=c(47,65,83), y=c(0,0,0),
                                 u=sqrt(c(50,100,150)**2/2),
                                 v=sqrt(c(50,100,150)**2/2)),
                 aes(x = x - u*facW1/2, y = y-v*facW1/2,
                     xend=x+u*facW1/2, yend=y+v*facW1/2),
                 arrow = arrow(length = unit(0.15,"cm"))) + 
    geom_text(data=data.frame(x=c(47,65,83), y=-rep(6,3), text=c("50","100","150")),
              aes(x=x, y=y, label=text), size = 5.5)
  
  
  
  facW1 <- 0.02
  p <- arrangeGrob(nrow=3, widths=c(1, 20), heights = c(1.5, 20, 3), 
                   blank_ggplot(""), 
                   arrangeGrob(blank_ggplot(""),
                               blank_ggplot("Low Q700", fontface = "bold"), 
                               blank_ggplot("High Q700", fontface = "bold"), 
                               ncol=3, widths=c(1,20,20)), 
                   arrangeGrob(blank_ggplot("-4 days", angle = 90, fontface = "bold"),
                               blank_ggplot("-2 days", angle = 90, fontface = "bold"),
                               blank_ggplot("no lag", angle = 90, fontface = "bold"), ncol=1), 
                   arrangeGrob(nrow=3, ncol=2, 
                               plot_PW(low-32)  + annotate("label", x=37, y=45, label="A)", 
                                                           size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                               plot_PW(high-32)  + annotate("label", x=37, y=45, label="B)",
                                                            size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                               plot_PW(low-16)     + annotate("label", x=37, y=45, label="C)"
                                                              , size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                               plot_PW(high-16) + annotate("label", x=37, y=45, label="D)",
                                                           size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                               plot_PW(low) + annotate("label", x=37, y=45, label="E)",
                                                       size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                               plot_PW(high)    + annotate("label", x=37, y=45, label="F)"
                                                           , size=10, label.padding = unit(c(.6), "lines"), alpha=.5)),
                   blank_ggplot(""),
                   arrangeGrob(nrow = 1, legend_anom,
                               arrangeGrob(nrow=2, 
                                           blank_ggplot(expression(bold(atop("Vertical integral of water",
                                                                             "vapour flux (kg.m."*s^"-1"*")"))), size = 7),
                                           p_wind )))
  
  
  ggsave("figures/Fig11_Qdiff_comp_PW-2.pdf", p, device="pdf", width=12, height=15)
  
  

###############################################################################
########## Figure 12: Altitude horizontal composite based on Q700 QR ##########
###############################################################################

  
  p <- arrangeGrob(nrow=2, widths=c(1, 10), heights = c(1, 20), 
                   blank_ggplot(""), 
                   arrangeGrob(blank_ggplot("-2 days", fontface = "bold"),
                               blank_ggplot("no lag", fontface = "bold"), ncol=2), 
                   arrangeGrob(blank_ggplot("Low Q700", rot = T, fontface = "bold"), 
                               blank_ggplot("High Q700", rot = T, fontface = "bold"), 
                               blank_ggplot(""), ncol=1, heights = c(3,3,1.5)), 
                   ggarrange(nrow=2, ncol=2, common.legend=T, legend="bottom",
                             plot_WD(z300, dz300_500, low - 16 , seq(-135,45,15), seq(-45,45,15)) + # 502 -944.088 59 38
                               annotate("label", x=54, y=47.5, label="A)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, low + 0  , seq(-135,45,15), seq(-45,45,15)) + # 590 -1390.77 65 36
                               annotate("label", x=54, y=47.5, label="B)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, high - 16 , seq(-135,45,15), seq(-45,45,15)) + # 698 -567.9388 50 33
                               annotate("label", x=54, y=47.5, label="C)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5),
                             plot_WD(z300, dz300_500, high + 0  , seq(-135,45,15), seq(-45,45,15)) + # 673 -812.8214 66 34
                               annotate("label", x=54, y=47.5, label="D)", size=10, label.padding = unit(c(.6), "lines"), alpha=.5)))
  
  ggsave("figures/Fig12_Qdiff_comp_lagH.pdf", p, device="pdf", width=12, height=12.5)   
  


    
    